@@ -2,6 +2,7 @@
 #
 # This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
+from __future__ import print_function
 
 import os
 import pkg_resources
@@ -20,15 +21,10 @@ from gunicorn.config import Config, get_default_config_file
 from gunicorn import util
 
 
-def _configure_logging_from_paste_config(paste_file):
-    logger_cfg_file = paste_file.split(':')[1]
+def _has_logging_config(paste_file):
     cfg_parser = ConfigParser.ConfigParser()
-    cfg_parser.read([logger_cfg_file])
-    if cfg_parser.has_section('loggers'):
-        from logging.config import fileConfig
-        config_file = os.path.abspath(logger_cfg_file)
-        fileConfig(config_file, dict(__file__=config_file,
-                                     here=os.path.dirname(config_file)))
+    cfg_parser.read([paste_file])
+    return cfg_parser.has_section('loggers')
 
 
 def paste_config(gconfig, config_url, relative_to, global_conf=None):
@@ -38,7 +34,7 @@ def paste_config(gconfig, config_url, relative_to, global_conf=None):
 
     config_url = config_url.split('#')[0]
     cx = loadwsgi.loadcontext(SERVER, config_url, relative_to=relative_to,
-            global_conf=global_conf)
+                              global_conf=global_conf)
     gc, lc = cx.global_conf.copy(), cx.local_conf.copy()
     cfg = {}
 
@@ -48,12 +44,12 @@ def paste_config(gconfig, config_url, relative_to, global_conf=None):
     elif host:
         cfg['bind'] = host.split(',')
 
-    cfg['workers'] = int(lc.get('workers', 1))
-    cfg['umask'] = int(lc.get('umask', 0))
     cfg['default_proc_name'] = gc.get('__file__')
 
     # init logging configuration
-    _configure_logging_from_paste_config(config_url)
+    config_file = config_url.split(':')[1]
+    if _has_logging_config(config_file):
+        cfg.setdefault('logconfig', config_file)
 
     for k, v in gc.items():
         if k not in gconfig.settings:
@@ -126,7 +122,7 @@ class PasterServerApplication(PasterBaseApplication):
 
     def __init__(self, app, gcfg=None, host="127.0.0.1", port=None, *args, **kwargs):
         self.cfg = Config()
-        self.gcfg = gcfg # need to hold this for app_config
+        self.gcfg = gcfg  # need to hold this for app_config
         self.app = app
         self.callable = None
 
@@ -155,7 +151,7 @@ class PasterServerApplication(PasterBaseApplication):
                 if k.lower() in self.cfg.settings and v is not None:
                     self.cfg.set(k.lower(), v)
         except Exception as e:
-            sys.stderr.write("\nConfig error: %s\n" % str(e))
+            print("\nConfig error: %s" % str(e), file=sys.stderr)
             sys.stderr.flush()
             sys.exit(1)
 
