@@ -12,6 +12,7 @@ from logging.config import fileConfig
 import os
 import socket
 import sys
+import threading
 import traceback
 
 from gunicorn import util
@@ -186,6 +187,8 @@ class Logger(object):
         self.access_log.propagate = False
         self.error_handlers = []
         self.access_handlers = []
+        self.logfile = None
+        self.lock = threading.Lock()
         self.cfg = cfg
         self.setup(cfg)
 
@@ -195,13 +198,21 @@ class Logger(object):
         self.access_log.setLevel(logging.INFO)
 
         # set gunicorn.error handler
+        if self.cfg.capture_output and cfg.errorlog != "-":
+            for stream in sys.stdout, sys.stderr:
+                stream.flush()
+
+            self.logfile = open(cfg.errorlog, 'a+')
+            os.dup2(self.logfile.fileno(), sys.stdout.fileno())
+            os.dup2(self.logfile.fileno(), sys.stderr.fileno())
+
         self._set_handler(self.error_log, cfg.errorlog,
-                logging.Formatter(self.error_fmt, self.datefmt))
+                          logging.Formatter(self.error_fmt, self.datefmt))
 
         # set gunicorn.access handler
         if cfg.accesslog is not None:
             self._set_handler(self.access_log, cfg.accesslog,
-                fmt=logging.Formatter(self.access_fmt))
+                fmt=logging.Formatter(self.access_fmt), stream=sys.stdout)
 
         # set syslog handler
         if cfg.syslog:
@@ -292,6 +303,10 @@ class Logger(object):
         # add response headers
         atoms.update(dict([("{%s}o" % k.lower(), v) for k, v in resp_headers]))
 
+        # add environ variables
+        environ_variables = environ.items()
+        atoms.update(dict([("{%s}e" % k.lower(), v) for k, v in environ_variables]))
+
         return atoms
 
     def access(self, resp, req, environ, request_time):
@@ -318,6 +333,18 @@ class Logger(object):
         return time.strftime('[%d/%b/%Y:%H:%M:%S %z]')
 
     def reopen_files(self):
+        if self.cfg.capture_output and self.cfg.errorlog != "-":
+            for stream in sys.stdout, sys.stderr:
+                stream.flush()
+
+            with self.lock:
+                if self.logfile is not None:
+                    self.logfile.close()
+                self.logfile = open(self.cfg.errorlog, 'a+')
+                os.dup2(self.logfile.fileno(), sys.stdout.fileno())
+                os.dup2(self.logfile.fileno(), sys.stderr.fileno())
+
+
         for log in loggers():
             for handler in log.handlers:
                 if isinstance(handler, logging.FileHandler):
@@ -346,7 +373,7 @@ class Logger(object):
             if getattr(h, "_gunicorn", False):
                 return h
 
-    def _set_handler(self, log, output, fmt):
+    def _set_handler(self, log, output, fmt, stream=None):
         # remove previous gunicorn log handler
         h = self._get_gunicorn_handler(log)
         if h:
@@ -354,7 +381,7 @@ class Logger(object):
 
         if output is not None:
             if output == "-":
-                h = logging.StreamHandler()
+                h = logging.StreamHandler(stream)
             else:
                 util.check_is_writeable(output)
                 h = logging.FileHandler(output)
