@@ -3,5 +3,5 @@ request = {
     "uri": uri('/with_"quotes"?foo="bar"'),
     "version": (1, 1),
     "headers": [],
-    "body": ""
-}
\ No newline at end of file
+    "body": b""
+}
