@@ -10,9 +10,9 @@ import tempfile
 dirname = os.path.dirname(__file__)
 
 from gunicorn.http.parser import RequestParser
-from gunicorn.config import Config
 from gunicorn.six import BytesIO
 
+
 def data_source(fname):
     buf = BytesIO()
     with open(fname) as handle:
@@ -21,6 +21,7 @@ def data_source(fname):
             buf.write(line.encode('latin1'))
         return buf
 
+
 class request(object):
     def __init__(self, name):
         self.fname = os.path.join(dirname, "requests", name)
@@ -64,16 +65,3 @@ class FakeSocket(object):
 
     def seek(self, offset, whence=0):
         self.tmp.seek(offset, whence)
-
-
-class http_request(object):
-    def __init__(self, name):
-        self.fname = os.path.join(dirname, "requests", name)
-
-    def __call__(self, func):
-        def run():
-            fsock = FakeSocket(data_source(self.fname))
-            req = Request(Config(), fsock, ('127.0.0.1', 6000), ('127.0.0.1', 8000))
-            func(req)
-        run.func_name = func.func_name
-        return run
