@@ -3,8 +3,6 @@
 # This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
 
-import t
-
 import os
 import sys
 
@@ -12,6 +10,7 @@ import pytest
 
 from gunicorn import config
 from gunicorn.app.base import Application
+from gunicorn.errors import ConfigError
 from gunicorn.workers.sync import SyncWorker
 from gunicorn import glogging
 from gunicorn.instrument import statsd
@@ -24,6 +23,7 @@ def cfg_file():
 def paster_ini():
     return os.path.join(dirname, "..", "examples", "frameworks", "pylonstest", "nose.ini")
 
+
 class AltArgs(object):
     def __init__(self, args=None):
         self.args = args or []
@@ -35,6 +35,7 @@ class AltArgs(object):
     def __exit__(self, exc_type, exc_inst, traceback):
         sys.argv = self.orig
 
+
 class NoConfigApp(Application):
     def __init__(self):
         super(NoConfigApp, self).__init__("no_usage", prog="gunicorn_test")
@@ -51,6 +52,7 @@ def test_defaults():
     for s in config.KNOWN_SETTINGS:
         assert c.settings[s.name].validator(s.default) == c.settings[s.name].get()
 
+
 def test_property_access():
     c = config.Config()
     for s in config.KNOWN_SETTINGS:
@@ -92,6 +94,7 @@ def test_property_access():
     # No setting for name
     pytest.raises(AttributeError, c.set, "baz", "bar")
 
+
 def test_bool_validation():
     c = config.Config()
     assert c.preload_app is False
@@ -104,6 +107,7 @@ def test_bool_validation():
     pytest.raises(ValueError, c.set, "preload_app", "zilch")
     pytest.raises(TypeError, c.set, "preload_app", 4)
 
+
 def test_pos_int_validation():
     c = config.Config()
     assert c.workers == 1
@@ -118,6 +122,7 @@ def test_pos_int_validation():
     pytest.raises(ValueError, c.set, "workers", -21)
     pytest.raises(TypeError, c.set, "workers", c)
 
+
 def test_str_validation():
     c = config.Config()
     assert c.proc_name == "gunicorn"
@@ -125,6 +130,7 @@ def test_str_validation():
     assert c.proc_name == "foo"
     pytest.raises(TypeError, c.set, "proc_name", 2)
 
+
 def test_str_to_list_validation():
     c = config.Config()
     assert c.forwarded_allow_ips == ["127.0.0.1"]
@@ -136,6 +142,7 @@ def test_str_to_list_validation():
     assert c.forwarded_allow_ips == []
     pytest.raises(TypeError, c.set, "forwarded_allow_ips", 1)
 
+
 def test_callable_validation():
     c = config.Config()
     def func(a, b):
@@ -145,6 +152,18 @@ def test_callable_validation():
     pytest.raises(TypeError, c.set, "pre_fork", 1)
     pytest.raises(TypeError, c.set, "pre_fork", lambda x: True)
 
+
+def test_reload_engine_validation():
+    c = config.Config()
+
+    assert c.reload_engine == "auto"
+
+    c.set('reload_engine', 'poll')
+    assert c.reload_engine == 'poll'
+
+    pytest.raises(ConfigError, c.set, "reload_engine", "invalid")
+
+
 def test_callable_validation_for_string():
     from os.path import isdir as testfunc
     assert config.validate_callable(-1)("os.path.isdir") == testfunc
@@ -175,12 +194,22 @@ def test_cmd_line():
         app = NoConfigApp()
         assert app.cfg.preload_app
 
+
+def test_cmd_line_invalid_setting(capsys):
+    with AltArgs(["prog_name", "-q", "bar"]):
+        with pytest.raises(SystemExit):
+            NoConfigApp()
+        _, err = capsys.readouterr()
+        assert  "error: unrecognized arguments: -q" in err
+
+
 def test_app_config():
     with AltArgs():
         app = NoConfigApp()
     for s in config.KNOWN_SETTINGS:
         assert app.cfg.settings[s.name].validator(s.default) == app.cfg.settings[s.name].get()
 
+
 def test_load_config():
     with AltArgs(["prog_name", "-c", cfg_file()]):
         app = NoConfigApp()
@@ -188,6 +217,7 @@ def test_load_config():
     assert app.cfg.workers == 3
     assert app.cfg.proc_name == "fooey"
 
+
 def test_load_config_explicit_file():
     with AltArgs(["prog_name", "-c", "file:%s" % cfg_file()]):
         app = NoConfigApp()
@@ -195,6 +225,7 @@ def test_load_config_explicit_file():
     assert app.cfg.workers == 3
     assert app.cfg.proc_name == "fooey"
 
+
 def test_load_config_module():
     with AltArgs(["prog_name", "-c", "python:%s" % cfg_module()]):
         app = NoConfigApp()
@@ -202,18 +233,21 @@ def test_load_config_module():
     assert app.cfg.workers == 3
     assert app.cfg.proc_name == "fooey"
 
+
 def test_cli_overrides_config():
     with AltArgs(["prog_name", "-c", cfg_file(), "-b", "blarney"]):
         app = NoConfigApp()
     assert app.cfg.bind == ["blarney"]
     assert app.cfg.proc_name == "fooey"
 
+
 def test_cli_overrides_config_module():
     with AltArgs(["prog_name", "-c", "python:%s" % cfg_module(), "-b", "blarney"]):
         app = NoConfigApp()
     assert app.cfg.bind == ["blarney"]
     assert app.cfg.proc_name == "fooey"
 
+
 @pytest.fixture
 def create_config_file(request):
     default_config = os.path.join(os.path.abspath(os.getcwd()),
@@ -227,6 +261,7 @@ def create_config_file(request):
 
     return default
 
+
 def test_default_config_file(create_config_file):
     assert config.get_default_config_file() == create_config_file.name
 
@@ -234,6 +269,7 @@ def test_default_config_file(create_config_file):
         app = NoConfigApp()
     assert app.cfg.bind == ["0.0.0.0:9090"]
 
+
 def test_post_request():
     c = config.Config()
 
@@ -285,3 +321,52 @@ def test_always_use_configured_logger():
     c.set('statsd_host', 'localhost:12345')
     # still uses custom logger over statsd
     assert c.logger_class == MyLogger
+
+
+def test_load_enviroment_variables_config(monkeypatch):
+    monkeypatch.setenv("GUNICORN_CMD_ARGS", "--workers=4")
+    with AltArgs():
+        app = NoConfigApp()
+    assert app.cfg.workers == 4
+
+
+def test_invalid_enviroment_variables_config(monkeypatch, capsys):
+    monkeypatch.setenv("GUNICORN_CMD_ARGS", "--foo=bar")
+    with AltArgs():
+        with pytest.raises(SystemExit):
+            NoConfigApp()
+        _, err = capsys.readouterr()
+        assert  "error: unrecognized arguments: --foo" in err
+
+def test_cli_overrides_enviroment_variables_module(monkeypatch):
+    monkeypatch.setenv("GUNICORN_CMD_ARGS", "--workers=4")
+    with AltArgs(["prog_name", "-c", cfg_file(), "--workers", "3"]):
+        app = NoConfigApp()
+    assert app.cfg.workers == 3
+
+
+@pytest.mark.parametrize("options, expected", [
+    (["myapp:app"], False),
+    (["--reload", "myapp:app"], True),
+    (["--reload", "--", "myapp:app"], True),
+    (["--reload", "-w 2", "myapp:app"], True),
+])
+def test_reload(options, expected):
+    cmdline = ["prog_name"]
+    cmdline.extend(options)
+    with AltArgs(cmdline):
+        app = NoConfigApp()
+    assert app.cfg.reload == expected
+
+
+@pytest.mark.parametrize("options, expected", [
+    (["--umask 0", "myapp:app"], 0),
+    (["--umask", "0xFF", "myapp:app"], 255),
+    (["--umask", "0022", "myapp:app"], 18),
+])
+def test_umask_config(options, expected):
+    cmdline = ["prog_name"]
+    cmdline.extend(options)
+    with AltArgs(cmdline):
+        app = NoConfigApp()
+    assert app.cfg.umask == expected
